Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/trunk]: src/sys Spell busy correctly.
details: https://anonhg.NetBSD.org/src/rev/4a7d37ec8bd1
branches: trunk
changeset: 749530:4a7d37ec8bd1
user: skrll <skrll%NetBSD.org@localhost>
date: Tue Dec 01 23:16:00 2009 +0000
description:
Spell busy correctly.
diffstat:
sys/arch/ews4800mips/sbd/if_iee_sbdio.c | 12 ++++++------
sys/arch/hp700/gsc/if_iee_gsc.c | 18 +++++++++---------
sys/dev/ic/i82596var.h | 4 ++--
3 files changed, 17 insertions(+), 17 deletions(-)
diffs (124 lines):
diff -r da1437379301 -r 4a7d37ec8bd1 sys/arch/ews4800mips/sbd/if_iee_sbdio.c
--- a/sys/arch/ews4800mips/sbd/if_iee_sbdio.c Tue Dec 01 23:14:02 2009 +0000
+++ b/sys/arch/ews4800mips/sbd/if_iee_sbdio.c Tue Dec 01 23:16:00 2009 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: if_iee_sbdio.c,v 1.9 2009/05/10 04:26:19 tsutsui Exp $ */
+/* $NetBSD: if_iee_sbdio.c,v 1.10 2009/12/01 23:16:00 skrll Exp $ */
/*
* Copyright (c) 2003 Jochen Kunz.
@@ -30,7 +30,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_iee_sbdio.c,v 1.9 2009/05/10 04:26:19 tsutsui Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_iee_sbdio.c,v 1.10 2009/12/01 23:16:00 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -147,12 +147,12 @@
int
iee_sbdio_reset(struct iee_softc *sc)
{
-#define IEE_ISCP_BUSSY 0x1
+#define IEE_ISCP_BUSY 0x1
int n, retry = 8;
uint32_t cmd, ack;
/* Make sure the busy byte is set and the cache is flushed. */
- SC_ISCP(sc)->iscp_bussy = IEE_ISCP_BUSSY;
+ SC_ISCP(sc)->iscp_busy = IEE_ISCP_BUSY;
IEE_ISCPSYNC(sc, BUS_DMASYNC_PREREAD | BUS_DMASYNC_PREWRITE);
/* Setup the PORT Command with pointer to SCP. */
@@ -168,9 +168,9 @@
/* Wait for the chip to initialize and read SCP and ISCP. */
for (n = 0 ; n < retry; n++) {
IEE_ISCPSYNC(sc, BUS_DMASYNC_POSTREAD | BUS_DMASYNC_POSTWRITE);
- ack = SC_ISCP(sc)->iscp_bussy;
+ ack = SC_ISCP(sc)->iscp_busy;
IEE_ISCPSYNC(sc, BUS_DMASYNC_PREREAD);
- if (ack != IEE_ISCP_BUSSY) {
+ if (ack != IEE_ISCP_BUSY) {
break;
}
delay(100);
diff -r da1437379301 -r 4a7d37ec8bd1 sys/dev/ic/i82596var.h
--- a/sys/dev/ic/i82596var.h Tue Dec 01 23:14:02 2009 +0000
+++ b/sys/dev/ic/i82596var.h Tue Dec 01 23:16:00 2009 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: i82596var.h,v 1.14 2009/05/10 04:26:19 tsutsui Exp $ */
+/* $NetBSD: i82596var.h,v 1.15 2009/12/01 23:16:01 skrll Exp $ */
/*
* Copyright (c) 2003 Jochen Kunz.
@@ -51,7 +51,7 @@
/* Intermediate System Configuration Pointer */
struct iee_iscp {
- volatile uint16_t iscp_bussy; /* Even Word, bits 0..15 */
+ volatile uint16_t iscp_busy; /* Even Word, bits 0..15 */
volatile uint16_t iscp_pad; /* Odd Word, bits 16..32 */
volatile uint32_t iscp_scb_addr; /* address of SCB */
} __packed;
Home |
Main Index |
Thread Index |
Old Index
diff -r da1437379301 -r 4a7d37ec8bd1 sys/arch/hp700/gsc/if_iee_gsc.c
--- a/sys/arch/hp700/gsc/if_iee_gsc.c Tue Dec 01 23:14:02 2009 +0000
+++ b/sys/arch/hp700/gsc/if_iee_gsc.c Tue Dec 01 23:16:00 2009 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: if_iee_gsc.c,v 1.15 2009/05/24 06:53:35 skrll Exp $ */
+/* $NetBSD: if_iee_gsc.c,v 1.16 2009/12/01 23:16:01 skrll Exp $ */
/*
* Copyright (c) 2003 Jochen Kunz.
@@ -34,7 +34,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_iee_gsc.c,v 1.15 2009/05/24 06:53:35 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_iee_gsc.c,v 1.16 2009/12/01 23:16:01 skrll Exp $");
/* autoconfig and device stuff */
#include <sys/param.h>
@@ -82,7 +82,7 @@
#define IEE_GSC_RESET 0
#define IEE_GSC_PORT 4
#define IEE_GSC_CHANATT 8
-#define IEE_ISCP_BUSSY 0x1
+#define IEE_ISCP_BUSY 0x1
/* autoconfig stuff */
static int iee_gsc_match(device_t, cfdata_t, void *);
@@ -142,8 +142,8 @@
uint32_t cmd;
uint16_t ack;
- /* Make sure the bussy byte is set and the cache is flushed. */
- SC_ISCP(sc)->iscp_bussy = IEE_ISCP_BUSSY;
+ /* Make sure the busy byte is set and the cache is flushed. */
+ SC_ISCP(sc)->iscp_busy = IEE_ISCP_BUSY;
IEE_ISCPSYNC(sc, BUS_DMASYNC_PREREAD|BUS_DMASYNC_PREWRITE);
/* Setup the PORT Command with pointer to SCP. */
cmd = IEE_PORT_SCP | IEE_PHYS_SHMEM(sc->sc_scp_off);
@@ -170,9 +170,9 @@
/* Wait for the chip to initialize and read SCP and ISCP. */
for (n = 0 ; n < 1000; n++) {
IEE_ISCPSYNC(sc, BUS_DMASYNC_POSTREAD|BUS_DMASYNC_POSTWRITE);
- ack = SC_ISCP(sc)->iscp_bussy;
+ ack = SC_ISCP(sc)->iscp_busy;
IEE_ISCPSYNC(sc, BUS_DMASYNC_PREREAD);
- if (ack != IEE_ISCP_BUSSY)
+ if (ack != IEE_ISCP_BUSY)
break;
DELAY(100);
}
@@ -181,8 +181,8 @@
(sc->sc_iee_cmd)(sc, IEE_SCB_ACK);
return 0;
}
- printf("%s: iee_gsc_reset timeout bussy=0x%x\n",
- device_xname(sc->sc_dev), SC_ISCP(sc)->iscp_bussy);
+ printf("%s: iee_gsc_reset timeout busy=0x%x\n",
+ device_xname(sc->sc_dev), SC_ISCP(sc)->iscp_busy);
return -1;
}